//**************************************
// Class UTStatsLink
// Extend Logging from UTStats to eliminate the need for dual packages
// 06/27/07  extended from >> original package below.
//**************************************
// =============================================================================
//                        # # ### ### ###  #  ### ###
//                        # #  #  #    #  # #  #  #
//                        # #  #  ###  #  # #  #  ###
//                        # #  #    #  #  ###  #    #
//                        ###  #  ###  #  # #  #  ###
//                                 Beta 4.2
// =============================================================================
// UTStats Team:
//     * Azazel (Main PHP Coder)
//     * Toa (PHP Coder)
//     * AnthraX (Unrealscript Coder)
// UTStats Forum:
//     * http://www.unrealadmin.org/forums/forumdisplay.php?f=173
// Released under the Unreal Open MOD License (included in zip package)
// =============================================================================

class UTStatsLink extends StatLogFile;

var bool bFirstBlood;
var bool bGameStarted;

var string ComboCode[4];
var string Buffer;
var string Version;
var string MutatorList;

var float EndTime;
var float WarmupTime;

var int currentid;
var int PHPos;

struct PlayerInfo
{
   var Pawn Pawn;
   var int ID, Spree, Combo, Kills, Deaths, Suicides, TeamKills;
   var float LastKill, EndTime, JoinTime;
   var bool bHasFlag;
   var string Login, IP;
};
var PlayerInfo PI[33];


// =============================================================================
// Pregame functions
// =============================================================================

function LogStandardInfo()
{
    local int i;
    local string ServerActors;
    local mutator Mutator;
    local bool bInsta;

    //JM fix
    local WebServer ws;
    local string s;

    // Setup the buffer
    Buffer = "";

    // Setup the PI structs
    for (i = 0; i < 32; ++i)
        PI[i].ID = -1;

    // Setup the Combo array
    ComboCode[0] = "spree_dbl";
    ComboCode[1] = "spree_mult";
    ComboCode[2] = "spree_ult";
    ComboCode[3] = "spree_mon";

    // Check the serveractors list
    ServerActors = Level.ConsoleCommand("get Engine.GameEngine ServerActors");

    Log("### ___________________________________",'UTSTATS');
    Log("###                                    ",'UTSTATS');
    Log("###     # # ### ### ###  #  ### ###    ",'UTSTATS');
    Log("###     # #  #  #    #  # #  #  #      ",'UTSTATS');
    Log("###     # #  #  ###  #  # #  #  ###    ",'UTSTATS');
    Log("###     # #  #    #  #  ###  #    #    ",'UTSTATS');
    Log("###     ###  #  ###  #  # #  #  ###    ",'UTSTATS');
    Log("### ___________________________________",'UTSTATS');
    Log("###",'UTSTATS');
    Log("### - Version      : "$Version,'UTSTATS');
    Log("### ___________________________________",'UTSTATS');

    LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Log_Standard"$Chr(9)$"UTStats");
    LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Log_Version"$Chr(9)$Version);
    LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Game_Name"$Chr(9)$GameName);
    LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Game_Version"$Chr(9)$Level.EngineVersion);
    LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Absolute_Time"$Chr(9)$GetAbsoluteTime());

    if (bWorld)
    {
        if( Level.ConsoleCommand("get UdpServerUplink douplink") ~= string(true) )
            LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Server_Public"$Chr(9)$"1");
        else
            LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"Server_Public"$Chr(9)$"0");
    }

   // Check for insta
   foreach AllActors(class'Mutator',Mutator)
   {
       if (Mutator.IsA('InstaGibDM'))
           bInsta = true;
   }

   LogEventString(GetTimeStamp()$Chr(9)$"game"$Chr(9)$"insta"$chr(9)$string(bInsta));

   //JM Fix
   foreach Level.AllActors(class'WebServer', ws)
   {
	    if (ws != none)
	    {
	       s = mid(ws.ServerURL,InStr(ws.ServerURL,"//") + 2);
	       s = left(s,InStr(s,":"));
	       break;
	    }
   }
   LogIP(s);
}

function LogIP (string MyIP)
{
   LogEventString(GetTimeStamp()$Chr(9)$"info"$Chr(9)$"True_Server_IP"$Chr(9)$MyIP);
}

// =============================================================================
// LogPlayerInfo ~ Called right after a player connects
// =============================================================================

function LogPlayerInfo(Pawn Player)
{
   local int i, j;

   Super.LogPlayerInfo(Player);

   // Setup a playerinfo struct for this player
   for (i=0;i<32;++i)
   {
      if (PI[i].ID == -1) // This slot is free
         break;
   }

   PI[i].ID = Player.PlayerReplicationInfo.PlayerID;
   PI[i].Pawn = Player;
   PI[i].Spree = 0;
   PI[i].Combo = 1;
   PI[i].Kills = 0;
   PI[i].Deaths = 0;
   PI[i].Suicides = 0;
   PI[i].TeamKills = 0;
   PI[i].LastKill = 0.0;
   PI[i].EndTime = 0.0;
   PI[i].JoinTime = Level.TimeSeconds;
   PI[i].bHasFlag = false;
}

// =============================================================================
// LogKill ~ Called for each killevent
// =============================================================================

function LogKill( int KillerID, int VictimID, string KillerWeaponName, string VictimWeaponName, name DamageType )
{
    local int KID, VID;

    if (!bGameStarted && !GameStarted())
      return;


    KID = GetID(KillerID);
    VID = GetID(VictimID);

    if ( KID == -1 || VID == -1 )
        return;

    LogEventString(GetTimeStamp()$Chr(9)$"kill"$Chr(9)$KillerID$Chr(9)$KillerWeaponName$Chr(9)$VictimID$Chr(9)$VictimWeaponName$Chr(9)$DamageType);

    PI[KID].Kills++;
    PI[VID].Deaths++;

    if (!bFirstBlood)
    {
      LogEventString(GetTimeStamp()$chr(9)$"first_blood"$chr(9)$KillerID);
      bFirstBlood = true;
    }

    LogSpree (KID,VID);
    LogCombo(KID);

    if (PI[VID].bHasFlag)
    {
      LogEventString(GetTimeStamp()$chr(9)$"flag_kill"$chr(9)$KillerID);
      PI[VID].bHasFlag = false;
    }
}

// =============================================================================
// LogSpree ~ Handle killing sprees
// Note: killing sprees get logged when they end. If someone has a killing spree
// at the end of the game or while he disconnects, this function gets called
// with KillerID 33
// =============================================================================

function LogSpree (int KillerID,int VictimID)
{
    local int i;
    local string spree;

    if ( KillerID == -1 || VictimID == -1)
        return;

    if (KillerID != 33)
      PI[KillerID].Spree++;

    i = PI[VictimID].Spree;
    PI[VictimID].Spree = 0;

    if (i < 5) // No Spree
      return;
    else if (i<10)
      spree = "spree_kill";
    else if (i<15)
      spree = "spree_Rampage";
    else if (i<20)
      spree = "spree_dom";
    else if (i<25)
      spree = "spree_uns";
    else
      spree = "spree_god";

    LogEventString(GetTimeStamp()$Chr(9)$"spree"$chr(9)$spree$chr(9)$PI[VictimID].ID);
}

// =============================================================================
// LogCombo ~ Handle combos
// Note: combos get logged when they end.
// =============================================================================

function LogCombo (int KillerID, optional bool bEndGame,optional bool bDisconnect)
{
    local float Now;
    local int i;
    local string spree;

    if ( KillerID == -1 )
        return;

    if (bEndGame)
      Now = EndTime;
    else if (bDisconnect)
      Now = PI[KillerID].EndTime;
    else
      Now = Level.TimeSeconds;

    if (Now - PI[KillerID].LastKill < 3.0)
    {
      if ((bEndGame || bDisconnect) && (PI[KillerID].Combo > 1))  // Combo was still going on when player disconnected
        LogEventString(GetTimeStamp()$chr(9)$"spree"$chr(9)$ComboCode[Clamp(PI[KillerID].Combo-2,0,3)]$chr(9)$PI[KillerID].ID);
      else
        PI[KillerID].Combo++;
    }
    else
    {
      if (PI[KillerID].Combo > 1)
        LogEventString(GetTimeStamp()$chr(9)$"spree"$chr(9)$ComboCode[Clamp(PI[KillerID].Combo-2,0,3)]$chr(9)$PI[KillerID].ID);
      PI[KillerID].Combo = 1;
    }

    PI[KillerID].LastKill = Now;
}

// =============================================================================
// LogTeamKill ~ :/
// =============================================================================

function LogTeamKill( int KillerID, int VictimID, string KillerWeaponName, string VictimWeaponName, name DamageType )
{
   local int KID, VID;

   if (!Level.Game.IsA('TeamGamePlus'))
   {
       LogKill(KillerID,VictimID,KillerWeaponName,VictimWeaponName,DamageType);
       return;
   }

   if (!bGameStarted && !GameStarted())
     return;

   KID = GetID(KillerID);
   VID = GetID(VictimID);

   if ( KID == -1 || VID == -1 )
        return;

   PI[KID].TeamKills++;
   PI[VID].Deaths++;

   super.LogTeamKill(KillerID,VictimID,KillerWeaponName,VictimWeaponName,DamageType);

   if (PI[VID].bHasFlag)
      PI[VID].bHasFlag = false;
}

// =============================================================================
// LogSuicide
// =============================================================================

function LogSuicide (Pawn Killed, name DamageType, Pawn Instigator)
{
   local int KLZ;

   if (!bGameStarted && !GameStarted())
     return;

   KLZ = GetID(Killed.PlayerReplicationInfo.PlayerID);

   PI[KLZ].Suicides++;

   Super.LogSuicide(Killed,DamageType,Instigator);

   if (PI[KLZ].bHasFlag)
      PI[KLZ].bHasFlag = false;
}

// =============================================================================
// LogPlayerConnect ~ We don't like spectators
// =============================================================================

function LogPlayerConnect(Pawn Player, optional string Checksum)
{
    if (Player.IsA('Spectator'))
        return;

    super.LogPlayerConnect(Player,Checksum);
}

// =============================================================================
// LogPlayerDisconnect ~ Handle sprees/combos, then add to the buffer
// =============================================================================

function LogPlayerDisconnect(Pawn Player)
{
    local int i;

    if (Player.IsA('Spectator'))
        return;

    i = GetID(Player.PlayerReplicationInfo.PlayerID);

    LogEventString(GetTimeStamp()$Chr(9)$"player"$Chr(9)$"Disconnect"$Chr(9)$Player.PlayerReplicationInfo.PlayerID);

    PI[i].EndTime = Level.TimeSeconds;

    if (!bGameStarted && !GameStarted())
        return;

    LogSpree(33,i);
    LogCombo(i,,true);

    AddToBuffer(i);

    PI[i].ID = -1;
}

// =============================================================================
// LogSpecialEvent ~ Any gametype-specific event goes trough this function
// Note: we don't log translocation events as it's a lot of spam and it's not
// usefull at all
// =============================================================================

function LogSpecialEvent(string EventType, optional coerce string Arg1, optional coerce string Arg2, optional coerce string Arg3, optional coerce string Arg4)
{
    local int i;
    local string event;

    if ((InStr(EventType,"transloc") != -1) || (InStr(EventType,"dom_") != -1) && (Level.Game.NumPlayers == 0))
    {
        if (EventType=="translocate")
        {
            i = GetID(int(Arg1));
            PI[i].bHasFlag = false;
        }
    }
    else
    {
        super.LogSpecialEvent(EventType,Arg1,Arg2,Arg3,Arg4);
    }

    if (!bGameStarted && !GameStarted())
        return;

    if (EventType=="flag_taken" || EventType=="flag_pickedup")
    {
        i = GetID(int(Arg1));

        PI[i].bHasFlag = true;
    }
    else if (EventType=="flag_captured")
    {
        i = GetID(int(Arg1));

        PI[i].bHasFlag = false;
    }
}

// =============================================================================
// We're using the tick function to set IP's
// =============================================================================

function Tick (float DeltaTime)
{
   local Pawn NewPawn;

   super.Tick(DeltaTime);

   if (Level.Game.CurrentID > currentID)
   {
       for( NewPawn = Level.PawnList ; NewPawn!=None ; NewPawn = NewPawn.NextPawn )
       {
           if(NewPawn.bIsPlayer && NewPawn.PlayerReplicationInfo.PlayerID == currentID)
           {
	           SetIP(NewPawn);
			   break;
           }
       }
       ++currentID;
   }
}

function SetIP( Pawn Player)
{
   local string IP;
   local int i,j;
   local bool bReconnected;

   if (Player.IsA('PlayerPawn'))
     IP = PlayerPawn(Player).GetPlayerNetworkAddress();
   else
     IP = "0.0.0.0";

   IP = IPOnly(IP);

   LogEventString(GetTimeStamp()$Chr(9)$"player"$Chr(9)$"IP"$Chr(9)$Player.PlayerReplicationInfo.PlayerID$Chr(9)$IP);
}

function string IPOnly (string IP)
{
    if (InStr(IP,":") != -1)
         IP = Left(IP,InStr(IP,":"));

    return IP;
}

// =============================================================================
// Game Start/End functions
// =============================================================================

function LogGameStart()
{
    LogEventString(GetTimeStamp()$Chr(9)$"game_start");
}

function LogGameEnd( string Reason )
{
    local int i;

    EndTime = Level.TimeSeconds;

    Super.LogGameEnd(Reason);

    for (i=0;i<32;++i)
    {
       if (PI[i].ID != -1) // Player is still on the server
       {
         LogSpree(33,i);
         LogCombo(i,true);
         AddToBuffer(i);
         PI[i].ID = -1;
       }
    }
    ProcessBuffer();
}

// =============================================================================
// Some lame code here. We want UTStats to log all playerstats at the end of the
// game, not during the game. That's why we'll use a buffer.
// =============================================================================

function AddToBuffer ( int PlayerID )
{
    local float Efficiency,TTL,TimeOnServer;
    local int i;

    if (PI[PlayerID].Pawn == none)
        return;

    TimeOnServer = Min(Level.TimeSeconds-PI[PlayerID].JoinTime,Level.TimeSeconds-WarmupTime);

    if (PI[PlayerID].Deaths != 0)
      TTL = TimeOnServer/(PI[PlayerID].Deaths) ;
    else
      TTL = TimeOnServer;

    if ((PI[PlayerID].Kills+PI[PlayerID].Deaths+PI[PlayerID].Suicides+PI[PlayerID].TeamKills) == 0)
      Efficiency = 0.0;
    else
      Efficiency = float(PI[PlayerID].Kills)/float(PI[PlayerID].Kills+PI[PlayerID].Deaths+PI[PlayerID].Suicides+PI[PlayerID].TeamKills)*100.0;

    //BufferLog("stat_player","accuracy",PI[PlayerID].ID,string(Accuracy));
    BufferLog("stat_player","score",PI[PlayerID].ID,string(int(PI[PlayerID].Pawn.PlayerReplicationInfo.Score)));
    BufferLog("stat_player","frags",PI[PlayerID].ID,string(PI[PlayerID].Kills - PI[PlayerID].Suicides));
    BufferLog("stat_player","kills",PI[PlayerID].ID,string(PI[PlayerID].Kills));
    BufferLog("stat_player","deaths",PI[PlayerID].ID,string(PI[PlayerID].Deaths));
    BufferLog("stat_player","suicides",PI[PlayerID].ID,string(PI[PlayerID].Suicides));
    BufferLog("stat_player","teamkills",PI[PlayerID].ID,string(PI[PlayerID].TeamKills));
    BufferLog("stat_player","efficiency",PI[PlayerID].ID,string(Efficiency));
    BufferLog("stat_player","time_on_server",PI[PlayerID].ID,string(Level.TimeSeconds-PI[PlayerID].JoinTime));
    BufferLog("stat_player","ttl",PI[PlayerID].ID,string(TTL));

}

function BufferLog ( string Tag, string Type, int PlayerID, string Value )
{
    Buffer = Buffer$":::"$Tag$chr(9)$Type$chr(9)$string(PlayerID)$chr(9)$Value;
}

function ProcessBuffer () // This will cause extreme cpu usage on the server for a sec :)
{
    local int index,i;

    while (InStr(Buffer,":::") != -1)
    {
        index = InStr(Buffer,":::");

        LogEventString(GetTimeStamp()$chr(9)$Left(Buffer,index));
        Buffer = Mid(Buffer,index+3);
    }

    LogEventString(GetTimeStamp()$chr(9)$Buffer);

    if (Level.Game.IsA('TeamGamePlus')) // Requested by the php-coders :o
    {
        for (i=0;i<TeamGamePlus(Level.Game).MaxTeams;++i)
        {
            LogEventString(GetTimeStamp()$chr(9)$"teamscore"$chr(9)$string(i)$chr(9)$string(int(TeamGamePlus(Level.Game).Teams[i].Score)));
        }
    }
}

// =============================================================================
// Functions used to get the offset in the PI array
// =============================================================================

function int GetID (int pid)
{
    local int i;

    for (i=0;i<32;++i)
    {
       if (PI[i].ID == pid)
         return i;
    }

    return -1;
}


function LogPings ()
{
   if (!bGameStarted && !GameStarted())
     return;

   super.LogPings();
}

function LogItemActivate (Inventory Item, Pawn Other)
{
   if (!bGameStarted && !GameStarted())
     return;

   Super.LogItemActivate(Item,Other);
}

function LogItemDeactivate (Inventory Item, Pawn Other)
{
   if (!bGameStarted && !GameStarted())
     return;

   super.LogItemDeactivate(Item,Other);
}

function LogPickup (Inventory Item, Pawn Other)
{
   if (!bGameStarted && !GameStarted())
     return;

   super.LogPickup(Item,Other);
}

// =============================================================================
// Warmupmode
// =============================================================================

function bool GameStarted()
{
    if(DeathMatchPlus(Level.Game).bTournament && DeathMatchPlus(Level.Game).CountDown > 0)
        return false;
    else
    {
        if (!bGameStarted)
        {
            WarmupTime = Level.TimeSeconds;
            LogEventString(GetTimeStamp()$Chr(9)$"game"$chr(9)$"realstart");
        }

        bGameStarted = true;
        return true;
    }
}

// =============================================================================
// AddMutator ~ Add mutatorclass to our list
// =============================================================================

function AddMutator (Mutator M)
{
    MutatorList = MutatorList$":::"$M.class;
}

// =============================================================================
// LogMutatorList ~ Log the list
// =============================================================================

function LogMutatorList()
{
    local string Entry,Desc;
    local int Num;

    Entry = "(none)";

    while (Entry != "")
    {
        if ((InStr(CAPS(MutatorList),CAPS(Entry)) != -1) && Desc != "")
        {
            if (InStr(Desc,",") != -1)
                Desc = Left(Desc,InStr(Desc,","));
            LogEventString(GetTimeStamp()$chr(9)$"game"$chr(9)$"GoodMutator"$chr(9)$Desc);
        }
        GetNextIntDesc("Engine.Mutator",Num++,Entry,Desc);
    }
}

// =============================================================================
// Defaultproperties
// =============================================================================

defaultproperties
{
    Version="0.4.2"
}
